# (unnamed project)

## Install

```bash
pip install swibin
```

To use, run your script like this:

```
swibin path/to/script.py
```



To test locally:

```bash
pip -m install -e .
python src/test/main.py
```
